@@ -19,20 +19,20 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-import unittest2
+import unittest
 import datetime
 import logging
 
 from stalker.db.session import DBSession
 from stalker import (db, defaults, Group, Department, Project, Repository,
                      Sequence, Status, StatusList, Task, Type, User, Version,
-                     Ticket, Vacation)
+                     Ticket, Vacation, Client)
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
 
-class UserTest(unittest2.TestCase):
+class UserTest(unittest.TestCase):
     """Tests the user class
     """
 
@@ -419,6 +419,9 @@ class UserTest(unittest2.TestCase):
             .first()
         self.assertIsNotNone(self.test_admin)
 
+        # create test company
+        self.test_company = Client(name='Test Company')
+
         # create the default values for parameters
         self.kwargs = {
             'name': 'Erkan Ozgur Yilmaz',
@@ -431,7 +434,8 @@ class UserTest(unittest2.TestCase):
                        self.test_group2],
             'created_by': self.test_admin,
             'updated_by': self.test_admin,
-            'efficiency': 1.0
+            'efficiency': 1.0,
+            'company': self.test_company
         }
 
         # create a proper user object
@@ -454,9 +458,8 @@ class UserTest(unittest2.TestCase):
         """
         self.assertFalse(User.__auto_name__)
 
-    def test_email_argument_accepting_only_string_or_unicode(self):
-        """testing if email argument accepting only string or unicode
-        values
+    def test_email_argument_accepting_only_string(self):
+        """testing if email argument accepting only string values
         """
         # try to create a new user with wrong attribute
         test_values = [1, 1.3, ["an email"], {"an": "email"}]
@@ -465,11 +468,10 @@ class UserTest(unittest2.TestCase):
             self.kwargs["email"] = test_value
             self.assertRaises(TypeError, User, **self.kwargs)
 
-    def test_email_attribute_accepting_only_string_or_unicode(self):
-        """testing if email attribute accepting only string or unicode
-        values
+    def test_email_attribute_accepting_only_string(self):
+        """testing if email attribute accepting only string values
         """
-        # try to assign something else than a string or unicode
+        # try to assign something else than a string
         test_value = 1
 
         self.assertRaises(
@@ -506,7 +508,7 @@ class UserTest(unittest2.TestCase):
             self.assertRaises(ValueError, User, **self.kwargs)
 
     def test_email_attribute_format(self):
-        """testing if given an email in wrong format will raise a ValueError 
+        """testing if given an email in wrong format will raise a ValueError
         """
         test_values = [
             "an email in no format",
@@ -515,7 +517,8 @@ class UserTest(unittest2.TestCase):
             "@",
             "eoyilmaz@",
             "eoyilmaz@some.compony@com",
-            ]
+        ]
+
         # any of these email values should raise a ValueError
         for value in test_values:
             self.assertRaises(
@@ -618,7 +621,7 @@ class UserTest(unittest2.TestCase):
             (" eRkAn", "erkan"),
             (" eRkan ozGur", "erkanozgur"),
             ("213 e.ozgur", "eozgur"),
-            ]
+        ]
 
         for valuePair in test_values:
             # set the input and expect the expected output
@@ -744,7 +747,7 @@ class UserTest(unittest2.TestCase):
         empty list
         """
         self.kwargs['departments'] = []
-        new_user = User(**self.kwargs)
+        User(**self.kwargs)
 
     def test_departments_attribute_is_an_empty_list(self):
         """testing if the departments attribute can be set to an empty list
@@ -787,8 +790,10 @@ class UserTest(unittest2.TestCase):
         """
         # try to set and get the same value back
         self.test_user.departments = [self.test_department2]
-        self.assertItemsEqual(self.test_user.departments,
-                              [self.test_department2])
+        self.assertEqual(
+            sorted(self.test_user.departments, key=lambda x: x.name),
+            sorted([self.test_department2], key=lambda x: x.name)
+        )
 
     def test_departments_attribute_supports_appending(self):
         """testing if departments attribute supports appending
@@ -796,8 +801,11 @@ class UserTest(unittest2.TestCase):
         self.test_user.departments = []
         self.test_user.departments.append(self.test_department1)
         self.test_user.departments.append(self.test_department2)
-        self.assertItemsEqual(self.test_user.departments,
-                              [self.test_department1, self.test_department2])
+        self.assertEqual(
+            sorted(self.test_user.departments, key=lambda x: x.name),
+            sorted([self.test_department1, self.test_department2],
+                   key=lambda x: x.name)
+        )
 
     def test_password_argument_being_None(self):
         """testing if a TypeError will be raised when trying to assign None
@@ -830,8 +838,8 @@ class UserTest(unittest2.TestCase):
         """
         test_password = "a new test password"
         self.kwargs["password"] = test_password
-        aNew_user = User(**self.kwargs)
-        self.assertNotEquals(aNew_user.password, test_password)
+        new_user = User(**self.kwargs)
+        self.assertNotEquals(new_user.password, test_password)
 
     def test_password_attribute_being_scrambled(self):
         """testing if password is scrambled when trying to store it
@@ -956,7 +964,10 @@ class UserTest(unittest2.TestCase):
         """
         test_list = [self.test_project1, self.test_project2]
         self.test_user.projects = test_list
-        self.assertItemsEqual(test_list, self.test_user.projects)
+        self.assertEqual(
+            sorted(test_list, key=lambda x: x.name),
+            sorted(self.test_user.projects, key=lambda x: x.name)
+        )
         self.test_user.projects.append(self.test_project3)
         self.assertIn(self.test_project3, self.test_user.projects)
         # also check the backref
@@ -1163,9 +1174,10 @@ class UserTest(unittest2.TestCase):
         self.assertTrue(len(self.test_user.tickets) > 0)
 
         # now check for exact items
-        self.assertItemsEqual(
-            self.test_user.tickets,
-            [self.test_ticket2, self.test_ticket3, self.test_ticket4]
+        self.assertEqual(
+            sorted(self.test_user.tickets, key=lambda x: x.name),
+            sorted([self.test_ticket2, self.test_ticket3, self.test_ticket4],
+                   key=lambda x: x.name)
         )
 
     def test_open_tickets_attribute_returns_all_open_tickets_owned_by_this_user(self):
@@ -1201,9 +1213,9 @@ class UserTest(unittest2.TestCase):
         self.assertTrue(len(self.test_user.open_tickets) > 0)
 
         # now check for exact items
-        self.assertItemsEqual(
-            self.test_user.open_tickets,
-            [
+        self.assertEqual(
+            sorted(self.test_user.open_tickets, key=lambda x: x.name),
+            sorted([
                 self.test_ticket1,
                 self.test_ticket2,
                 self.test_ticket3,
@@ -1212,27 +1224,26 @@ class UserTest(unittest2.TestCase):
                 self.test_ticket6,
                 self.test_ticket7,
                 self.test_ticket8,
-            ]
+            ], key=lambda x: x.name)
         )
 
         # close a couple of them
-        from stalker.models.ticket import (FIXED, CANTFIX, WONTFIX, DUPLICATE,
-                                           WORKSFORME, INVALID)
+        from stalker.models.ticket import FIXED, CANTFIX, INVALID
 
         self.test_ticket1.resolve(self.test_user, FIXED)
         self.test_ticket2.resolve(self.test_user, INVALID)
         self.test_ticket3.resolve(self.test_user, CANTFIX)
 
         # new check again
-        self.assertItemsEqual(
-            self.test_user.open_tickets,
-            [
+        self.assertEqual(
+            sorted(self.test_user.open_tickets, key=lambda x: x.name),
+            sorted([
                 self.test_ticket4,
                 self.test_ticket5,
                 self.test_ticket6,
                 self.test_ticket7,
                 self.test_ticket8
-            ]
+            ], key=lambda x: x.name)
         )
 
     def test_tjp_id_is_working_properly(self):
@@ -1244,7 +1255,9 @@ class UserTest(unittest2.TestCase):
         """testing if the to_tjp property is working properly
         """
         expected_tjp = \
-            'resource User_82 "Erkan Ozgur Yilmaz" {\n    efficiency 1.0\n}'
+            'resource User_%s "Erkan Ozgur Yilmaz" {\n    efficiency 1.0\n}' \
+            % self.test_user.id
+
         self.assertEqual(expected_tjp, self.test_user.to_tjp)
 
     def test_to_tjp_is_working_properly_for_a_user_with_vacations(self):
@@ -1257,28 +1270,30 @@ class UserTest(unittest2.TestCase):
             target_entity_type='Vacation'
         )
 
-        vac1 = Vacation(
+        Vacation(
             user=self.test_user,
             type=personal_vacation,
             start=datetime.datetime(2013, 6, 7, 0, 0),
             end=datetime.datetime(2013, 6, 21, 0, 0)
         )
 
-        vac2 = Vacation(
+        Vacation(
             user=self.test_user,
             type=personal_vacation,
             start=datetime.datetime(2013, 7, 1, 0, 0),
             end=datetime.datetime(2013, 7, 15, 0, 0)
         )
 
-        expected_tjp = """resource User_82 "Erkan Ozgur Yilmaz" {
+        expected_tjp = """resource User_%s "Erkan Ozgur Yilmaz" {
     efficiency 1.0
     vacation 2013-06-07-00:00:00 - 2013-06-21-00:00:00
     vacation 2013-07-01-00:00:00 - 2013-07-15-00:00:00
-}"""
+}""" % self.test_user.id
+
         # print expected_tjp
         # print '---------------'
         # print self.test_user.to_tjp
+
         self.assertEqual(
             expected_tjp,
             self.test_user.to_tjp
@@ -1370,12 +1385,12 @@ class UserTest(unittest2.TestCase):
         """
         self.kwargs['efficiency'] = 'not a float or integer'
         with self.assertRaises(TypeError) as cm:
-            new_user = User(**self.kwargs)
+            User(**self.kwargs)
 
         self.assertEqual(
             'User.efficiency should be a float number greater or equal to '
             '0.0, not str',
-            cm.exception.message
+            str(cm.exception)
         )
 
     def test_efficiency_attribute_is_not_a_float_or_integer(self):
@@ -1388,7 +1403,7 @@ class UserTest(unittest2.TestCase):
         self.assertEqual(
             'User.efficiency should be a float number greater or equal to '
             '0.0, not str',
-            cm.exception.message
+            str(cm.exception)
         )
 
     def test_efficiency_argument_is_a_negative_float_or_integer(self):
@@ -1397,12 +1412,12 @@ class UserTest(unittest2.TestCase):
         """
         self.kwargs['efficiency'] = -1
         with self.assertRaises(ValueError) as cm:
-            new_user = User(**self.kwargs)
+            User(**self.kwargs)
 
         self.assertEqual(
             'User.efficiency should be a float number greater or equal to '
             '0.0, not -1',
-            cm.exception.message
+            str(cm.exception)
         )
 
     def test_efficiency_attribute_is_a_negative_float_or_integer(self):
@@ -1415,7 +1430,7 @@ class UserTest(unittest2.TestCase):
         self.assertEqual(
             'User.efficiency should be a float number greater or equal to '
             '0.0, not -2.0',
-            cm.exception.message
+            str(cm.exception)
         )
 
     def test_efficiency_argument_is_working_properly(self):
@@ -1464,3 +1479,57 @@ class UserTest(unittest2.TestCase):
             2.3,
             self.test_user.efficiency
         )
+
+    def test_company_argument_is_skipped(self):
+        """testing if the company attribute will be set to None when the
+        company argument is skipped
+        """
+        try:
+            self.kwargs.pop('company')
+        except KeyError:
+            pass
+        new_user = User(**self.kwargs)
+        self.assertEquals(new_user.company, None)
+
+    def test_company_argument_is_None(self):
+        """testing if the company argument can be set to None
+        """
+        self.kwargs['company'] = None
+        new_user = User(**self.kwargs)
+        self.assertIsNone(new_user.company)
+
+    def test_company_attribute_is_set_to_None(self):
+        """testing if the company attribute can be set to None
+        """
+        self.assertIsNotNone(self.test_user.company)
+        self.test_user.company = None
+        self.assertIsNone(self.test_user.company)
+
+    def test_company_argument_is_not_a_Client_instance(self):
+        """testing if a TypeError will be raised when the company argument is
+        not a Client instance
+        """
+        test_values = [1, 1.2, "a user", ["a", "user"], {"a": "user"}]
+
+        for test_value in test_values:
+            self.kwargs["company"] = test_value
+            self.assertRaises(
+                TypeError,
+                User,
+                **self.kwargs
+            )
+
+    def test_company_attribute_is_set_to_a_value_other_than_a_Client_instance(self):
+        """testing if a TypeError will be raised when the company attribute is
+        set to a value other than a Client instance
+        """
+        test_values = [1, 1.2, "a user", ["a", "user"], {"a": "user"}]
+
+        for test_value in test_values:
+            self.assertRaises(
+                TypeError,
+                setattr,
+                self.test_user,
+                'company',
+                test_value
+            )
